


module Hermes
  #Il représente une pièce à fournir et contient
  # un statut (pièce manquante, contrôle en cours, pièce rejetée, pièce valide),
  # une liste des codes erreurs remontés,
  # et le lien vers le ou les fichiers.
  #
  #il est lié à un ou plusieurs applicant, ainsi,
  # une pièce peut être retrouvée et resservir pour plusieurs housingRequestFolder
  class RequiredDocument
    include Hermes::Concerns::CommonFieldsConcern
  
    field :type, type: String #type de piece à fournir, correspond au nom de la famille sur KYC
    field :category, type: String
    field :validity_limit, type: Date #Duréle limite de validité , nil= infini
    field :status, type: String #status de la piece (validée, traitement en cours, erreur)
    field :validation_errors, type: String #liste de erreurs renvoyées par le KYC
    field :tagset_id, type: String #id de l'espace de travail correspondant
    field :tagsetLocation, type: String #url du serveur sur lequel est stokée le document, nil si c'est en interne
    field :doc_ids, type: Array
    field :folder_where_is_required_for_consultation, type: Array
    field :folder_where_is_required_for_application, type: Array
    belongs_to :applicant, class_name: 'Hermes::Applicant', index: true
   
    
    writer_roles 'Superadmin', 'Administrator'
    reader_roles 'Manager'
    owner_field :user_id
    
    def create_tagset
      Tagset.create(is_space: true, title: applicant.full_name + " -- " + type)
    end
    def create_doc(filename, blob)
      doc = Doc.create(type: 'file', title: filename, tagset_ids: [self.tagset_id])
      doc.blob= blob
      doc.save
      doc
    end
    
    def set_blobs(array_of_blobs)
      #reset du status du document
      self.status = "controle en cours"
      self.validation_errors = ""
      self.validity_limit = nil
      self.tagset_id = create_tagset.id
      array_of_doc_ids =[]
      array_of_blobs.each do |item|
        doc = create_doc(item[:filename], item[:blob])
        array_of_doc_ids.push( doc.id.to_s)
      end
      self.doc_ids = array_of_doc_ids
      
    end
  end
end